Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Duet3D/RepRapFirmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Crocker <dcrocker@eschertech.com>2018-05-22 19:05:23 +0300
committerDavid Crocker <dcrocker@eschertech.com>2018-05-22 19:05:23 +0300
commit6e36b21aa1ae78e23a2c7adbc81761369a2358cf (patch)
treeb3070b522380f4fb3c0ac3ea84753d064ae2f685 /src/Networking/HttpResponder.h
parent9b2316ae90e816beae6cbc16538d203264a8162f (diff)
Veriosn 2.0RC5/1.21.1RC5
New features: - Added S3 option to M20 to get file list including size, date/time etc. Bug fixes: - HTTP request parsing error recovery didn't work. One consequence was that connecting from Internet Explorer crashed the Duet. - Spurious stall warnings were sometimes generated when simulating a print - The print monitor didn't think the print had started until a nozzle had reached target temperature. This meant that layer counting didn't work on machines with on tool heaters, or when the tool temperatures were fluctuating. - The print monitor didn't count layers when simulating a print - Axes beyond Z were ignored in G2/G3 moves - DWC and the Duet could deadlock if the Duet ran out of output buffers
Diffstat (limited to 'src/Networking/HttpResponder.h')
-rw-r--r--src/Networking/HttpResponder.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/Networking/HttpResponder.h b/src/Networking/HttpResponder.h
index d19decba..ddc7e8fa 100644
--- a/src/Networking/HttpResponder.h
+++ b/src/Networking/HttpResponder.h
@@ -37,7 +37,8 @@ private:
static const size_t MaxQualKeys = 5; // max number of key/value pairs in the qualifier
static const size_t MaxHeaders = 30; // max number of key/value pairs in the headers
static const uint32_t HttpSessionTimeout = 8000; // HTTP session timeout in milliseconds
- static const uint32_t MaxFileInfoGetTime = 1800; // maximum length of time we spend getting file info, to avoid the client timing out (actual time will be a little longer than this)
+ static const uint32_t MaxFileInfoGetTime = 2000; // maximum length of time we spend getting file info, to avoid the client timing out (actual time will be a little longer than this)
+ static const uint32_t MaxBufferWaitTime = 1000; // maximum length of time we spend waiting for a buffer before we discard gcodeReply buffers
enum class HttpParseState
{